[![CI](https://github.com/basxsoftwareassociation/bread/actions/workflows/main.yml/badge.svg)](https://github.com/basxsoftwareassociation/bread/actions/workflows/main.yml)
[![Documentation Status](https://readthedocs.org/projects/basx-bread/badge/?version=latest)](https://basx-bread.readthedocs.io/en/latest/?badge=latest)
[![Translation status](https://hosted.weblate.org/widgets/basxconnect/-/bread/svg-badge.svg)](https://hosted.weblate.org/engage/basxconnect/)

Important
=========

This repo is in alpha-stage and highly experimental. We will not keep any backwards-compatability during the next few months. We work on improving stability as well as adding documentation and tests.

Documentation
-------------

Documentation is hosted at [readthedocs.io](https://basx-bread.readthedocs.io/en/latest/)

TODO before going to beta
-------------------------

- [ ] Finish this readme
- [ ] Documentation, partly prepared under docs, using the sphinx documentation system
- [x] Create readthedocs deployment
- [x] Some of the carbon-components still need to be implemented
- [x] Add index here: https://djangopackages.org/grids/
- [x] Create pip-distribution
- [ ] Review test-system, make test-runner
- [x] Enforce python standards: black, isort, flake8, bandit (https://github.com/psf/black/blob/master/docs/compatible_configs.md, for black-flake8)
- [ ] Review and complete tox


BREAD Engine
------------

This package provides functionality to create django database applications in a quick and customizable way.

Installation
------------

```bash
pip install basx-bread
```
